pub struct CloudDlpDataProfile {
pub data_profile: Option<String>,
pub info_types: Option<Vec<InfoType>>,
pub parent_type: Option<String>,
}Expand description
The data profile associated with the finding.
This type is not used in any activity, and only used as part of another schema.
Fields
data_profile: Option<String>Name of the data profile, for example, projects/123/locations/europe/tableProfiles/8383929.
info_types: Option<Vec<InfoType>>Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type.
parent_type: Option<String>The resource hierarchy level at which the data profile was generated.