DataRetentionDeletionEvent

Struct DataRetentionDeletionEvent 

pub struct DataRetentionDeletionEvent {
    pub data_object_count: Option<i64>,
    pub event_detection_time: Option<DateTime<Utc>>,
    pub event_type: Option<String>,
    pub max_retention_allowed: Option<Duration>,
}
Details about data retention deletion violations, in which the data is non-compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.

This type is not used in any activity, and only used as part of another schema.

Fields

data_object_count: Option<i64>

Number of objects that violated the policy for this resource. If the number is less than 1,000, then the value of this field is the exact number. If the number of objects that violated the policy is greater than or equal to 1,000, then the value of this field is 1000.

event_detection_time: Option<DateTime<Utc>>

Timestamp indicating when the event was detected.

event_type: Option<String>

Type of the DRD event.

max_retention_allowed: Option<Duration>

Maximum duration of retention allowed from the DRD control. This comes from the DRD control where users set a max TTL for their data. For example, suppose that a user sets the max TTL for a Cloud Storage bucket to 90 days. However, an object in that bucket is 100 days old. In this case, a DataRetentionDeletionEvent will be generated for that Cloud Storage bucket, and the max_retention_allowed is 90 days.