pub struct Detection {
pub binary: Option<String>,
pub percent_pages_matched: Option<f64>,
}Expand description
Memory hash detection contributing to the binary family match.
This type is not used in any activity, and only used as part of another schema.
Fields
binary: Option<String>The name of the binary associated with the memory hash signature detection.
percent_pages_matched: Option<f64>The percentage of memory page hashes in the signature that were matched.