pub struct ExfilResource {
pub components: Option<Vec<String>>,
pub name: Option<String>,
}Expand description
Resource where data was exfiltrated from or exfiltrated to.
This type is not used in any activity, and only used as part of another schema.
Fields
components: Option<Vec<String>>Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames. For example, multiple tables might have been exfiltrated from the same Cloud SQL instance, or multiple files might have been exfiltrated from the same Cloud Storage bucket.
name: Option<String>The resource’s full resource name.