pub struct GoogleCloudSecuritycenterV1ResourceApplicationAttributes {
pub business_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>,
pub criticality: Option<GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality>,
pub developer_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>,
pub environment: Option<GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment>,
pub operator_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>,
}Expand description
Consumer provided attributes for the application
This type is not used in any activity, and only used as part of another schema.
Fields
business_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>Business team that ensures user needs are met and value is delivered
criticality: Option<GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality>User-defined criticality information.
developer_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>Developer team that owns development and coding.
environment: Option<GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment>User-defined environment information.
operator_owners: Option<Vec<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>>Operator team that ensures runtime and operations.