GoogleCloudSecuritycenterV1ResourceValueConfig

Struct GoogleCloudSecuritycenterV1ResourceValueConfig 

pub struct GoogleCloudSecuritycenterV1ResourceValueConfig {
    pub cloud_provider: Option<String>,
    pub create_time: Option<DateTime<Utc>>,
    pub description: Option<String>,
    pub name: Option<String>,
    pub resource_labels_selector: Option<HashMap<String, String>>,
    pub resource_type: Option<String>,
    pub resource_value: Option<String>,
    pub scope: Option<String>,
    pub sensitive_data_protection_mapping: Option<GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping>,
    pub tag_values: Option<Vec<String>>,
    pub update_time: Option<DateTime<Utc>>,
}
A resource value configuration (RVC) is a mapping configuration of user’s resources to resource values. Used in Attack path simulations.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

cloud_provider: Option<String>

Cloud provider this configuration applies to

create_time: Option<DateTime<Utc>>

Output only. Timestamp this resource value configuration was created.

description: Option<String>

Description of the resource value configuration.

name: Option<String>

Name for the resource value configuration

resource_labels_selector: Option<HashMap<String, String>>

List of resource labels to search for, evaluated with AND. For example, "resource_labels_selector": {"key": "value", "env": "prod"} will match resources with labels “key”: “value” AND “env”: “prod” https://cloud.google.com/resource-manager/docs/creating-managing-labels

resource_type: Option<String>

Apply resource_value only to resources that match resource_type. resource_type will be checked with AND of other resources. For example, “storage.googleapis.com/Bucket” with resource_value “HIGH” will apply “HIGH” value only to “storage.googleapis.com/Bucket” resources.

resource_value: Option<String>

Required. Resource value level this expression represents

scope: Option<String>

Project or folder to scope this configuration to. For example, “project/456” would apply this configuration only to resources in “project/456” scope will be checked with AND of other resources.

sensitive_data_protection_mapping: Option<GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping>

A mapping of the sensitivity on Sensitive Data Protection finding to resource values. This mapping can only be used in combination with a resource_type that is related to BigQuery, e.g. “bigquery.googleapis.com/Dataset”.

tag_values: Option<Vec<String>>

Required. Tag values combined with AND to check against. For Google Cloud resources, they are tag value IDs in the form of “tagValues/123”. Example: [ "tagValues/123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing

update_time: Option<DateTime<Utc>>

Output only. Timestamp this resource value configuration was last updated.