pub struct GroupAssetsResponse {
pub group_by_results: Option<Vec<GroupResult>>,
pub next_page_token: Option<String>,
pub read_time: Option<DateTime<Utc>>,
pub total_size: Option<i32>,
}Expand description
Response message for grouping by assets.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- assets group folders (response)
- assets group organizations (response)
- assets group projects (response)
Fields
group_by_results: Option<Vec<GroupResult>>Group results. There exists an element for each existing unique combination of property/values. The element contains a count for the number of times those specific property/values appear.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results.
read_time: Option<DateTime<Utc>>Time used for executing the groupBy request.
total_size: Option<i32>The total number of results matching the query.