pub struct IamPolicy {
pub policy_blob: Option<String>,
}Expand description
Cloud IAM Policy information associated with the Google Cloud resource described by the Security Command Center asset. This information is managed and defined by the Google Cloud resource and cannot be modified by the user.
This type is not used in any activity, and only used as part of another schema.
Fields
policy_blob: Option<String>The JSON representation of the Policy associated with the asset. See https://cloud.google.com/iam/reference/rest/v1/Policy for format details.