Kubernetes

Struct Kubernetes 

pub struct Kubernetes {
    pub access_reviews: Option<Vec<AccessReview>>,
    pub bindings: Option<Vec<GoogleCloudSecuritycenterV1Binding>>,
    pub node_pools: Option<Vec<NodePool>>,
    pub nodes: Option<Vec<Node>>,
    pub objects: Option<Vec<Object>>,
    pub pods: Option<Vec<Pod>>,
    pub roles: Option<Vec<Role>>,
}
Kubernetes-related attributes.

This type is not used in any activity, and only used as part of another schema.

Fields

access_reviews: Option<Vec<AccessReview>>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.

bindings: Option<Vec<GoogleCloudSecuritycenterV1Binding>>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.

node_pools: Option<Vec<NodePool>>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available.

nodes: Option<Vec<Node>>

Provides Kubernetes node information.

objects: Option<Vec<Object>>

Kubernetes objects related to the finding.

pods: Option<Vec<Pod>>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod.

roles: Option<Vec<Role>>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles.