pub struct ListBigQueryExportsResponse {
pub big_query_exports: Option<Vec<GoogleCloudSecuritycenterV1BigQueryExport>>,
pub next_page_token: Option<String>,
}Expand description
Response message for listing BigQuery exports.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- big query exports list folders (response)
- big query exports list organizations (response)
- big query exports list projects (response)
Fields
big_query_exports: Option<Vec<GoogleCloudSecuritycenterV1BigQueryExport>>The BigQuery exports from the specified parent.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.