pub struct ListEffectiveEventThreatDetectionCustomModulesResponse {
pub effective_event_threat_detection_custom_modules: Option<Vec<EffectiveEventThreatDetectionCustomModule>>,
pub next_page_token: Option<String>,
}Expand description
Response for listing EffectiveEventThreatDetectionCustomModules.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
effective_event_threat_detection_custom_modules: Option<Vec<EffectiveEventThreatDetectionCustomModule>>Effective custom modules belonging to the requested parent.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.