pub struct ListEventThreatDetectionCustomModulesResponse {
pub event_threat_detection_custom_modules: Option<Vec<EventThreatDetectionCustomModule>>,
pub next_page_token: Option<String>,
}Expand description
Response for listing Event Threat Detection custom modules.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
event_threat_detection_custom_modules: Option<Vec<EventThreatDetectionCustomModule>>Custom modules belonging to the requested parent.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.