pub struct ListFindingsResult {
pub finding: Option<Finding>,
pub resource: Option<Resource>,
pub state_change: Option<String>,
}Expand description
Result containing the Finding and its StateChange.
This type is not used in any activity, and only used as part of another schema.
Fields
finding: Option<Finding>Finding matching the search request.
resource: Option<Resource>Output only. Resource that is associated with this finding.
state_change: Option<String>State change of the finding between the points in time.