pub struct PortRange {
pub max: Option<i64>,
pub min: Option<i64>,
}Expand description
A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.
This type is not used in any activity, and only used as part of another schema.
Fields
max: Option<i64>Maximum port value.
min: Option<i64>Minimum port value.