Requests

Struct Requests 

pub struct Requests {
    pub long_term_allowed: Option<i32>,
    pub long_term_denied: Option<i32>,
    pub ratio: Option<f64>,
    pub short_term_allowed: Option<i32>,
}
Information about the requests relevant to the finding.

This type is not used in any activity, and only used as part of another schema.

Fields

long_term_allowed: Option<i32>

Allowed RPS (requests per second) over the long term.

long_term_denied: Option<i32>

Denied RPS (requests per second) over the long term.

ratio: Option<f64>

For ‘Increasing deny ratio’, the ratio is the denied traffic divided by the allowed traffic. For ‘Allowed traffic spike’, the ratio is the allowed traffic in the short term divided by allowed traffic in the long term.

short_term_allowed: Option<i32>

Allowed RPS (requests per second) in the short term.