pub struct ResourcePath {
pub nodes: Option<Vec<ResourcePathNode>>,
}Expand description
Represents the path of resources leading up to the resource this finding is about.
This type is not used in any activity, and only used as part of another schema.
Fields
nodes: Option<Vec<ResourcePathNode>>The list of nodes that make the up resource path, ordered from lowest level to highest level.