pub struct Vulnerability {
pub cve: Option<Cve>,
pub cwes: Option<Vec<Cwe>>,
pub fixed_package: Option<Package>,
pub offending_package: Option<Package>,
pub provider_risk_score: Option<i64>,
pub reachable: Option<bool>,
pub security_bulletin: Option<SecurityBulletin>,
}Expand description
Refers to common vulnerability fields e.g. cve, cvss, cwe etc.
This type is not used in any activity, and only used as part of another schema.
Fields
cve: Option<Cve>CVE stands for Common Vulnerabilities and Exposures (https://cve.mitre.org/about/)
cwes: Option<Vec<Cwe>>Represents one or more Common Weakness Enumeration (CWE) information on this vulnerability.
fixed_package: Option<Package>The fixed package is relevant to the finding.
offending_package: Option<Package>The offending package is relevant to the finding.
provider_risk_score: Option<i64>Provider provided risk_score based on multiple factors. The higher the risk score, the more risky the vulnerability is.
reachable: Option<bool>Represents whether the vulnerability is reachable (detected via static analysis)
security_bulletin: Option<SecurityBulletin>The security bulletin is relevant to this finding.