[][src]Struct google_securitycenter1::NotificationConfig

pub struct NotificationConfig {
    pub pubsub_topic: Option<String>,
    pub service_account: Option<String>,
    pub description: Option<String>,
    pub name: Option<String>,
    pub streaming_config: Option<StreamingConfig>,
}

Cloud Security Command Center (Cloud SCC) notification configs.

A notification config is a Cloud SCC resource that contains the configuration to send notifications for create/update events of findings, assets and etc.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

pubsub_topic: Option<String>

The PubSub topic to send notifications to. Its format is "projects/[project_id]/topics/[topic]".

service_account: Option<String>

Output only. The service account that needs "pubsub.topics.publish" permission to publish to the PubSub topic.

description: Option<String>

The description of the notification config (max of 1024 characters).

name: Option<String>

The relative resource name of this notification config. See: https://cloud.google.com/apis/design/resource_names#relative_resource_name Example: "organizations/{organization_id}/notificationConfigs/notify_public_bucket".

streaming_config: Option<StreamingConfig>

The config for triggering streaming-based notifications.