[][src]Struct google_securitycenter1::StreamingConfig

pub struct StreamingConfig {
    pub filter: Option<String>,
}

The config for streaming-based notifications, which send each event as soon as it is detected.

This type is not used in any activity, and only used as part of another schema.

Fields

filter: Option<String>

Expression that defines the filter to apply across create/update events of assets or findings as specified by the event type. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND.

Restrictions have the form <field> <operator> <value> and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource.

The supported operators are:

  • = for all value types.
  • >, <, >=, <= for integer values.
  • :, meaning substring matching, for strings.

The supported value types are:

  • string literals in quotes.
  • integer literals without quotes.
  • boolean literals true and false without quotes.