pub struct AwsOrganizationalUnit {
pub id: Option<String>,
pub name: Option<String>,
}Expand description
An Organizational Unit (OU) is a container of AWS accounts within a root of an organization. Policies that are attached to an OU apply to all accounts contained in that OU and in any child OUs.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The unique identifier (ID) associated with this OU. The regex pattern for an organizational unit ID string requires “ou-” followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second “-” dash and from 8 to 32 additional lowercase letters or digits. For example, “ou-ab12-cd34ef56”.
name: Option<String>The friendly name of the OU.