pub struct BulkMuteFindingsRequest {
pub filter: Option<String>,
pub mute_annotation: Option<String>,
pub mute_state: Option<String>,
}Expand description
Request message for bulk findings update. Note: 1. If multiple bulk update requests match the same resource, the order in which they get executed is not defined. 2. Once a bulk operation is started, there is no way to stop it.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- findings bulk mute folders (request)
- findings bulk mute organizations (request)
- findings bulk mute projects (request)
Fields
filter: Option<String>Expression that identifies findings that should be updated. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND. Restrictions have the form and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource. The supported operators are: * = for all value types. * >, <, >=, <= for integer values. * :, meaning substring matching, for strings. The supported value types are: * string literals in quotes. * integer literals without quotes. * boolean literals true and false without quotes.
mute_annotation: Option<String>This can be a mute configuration name or any identifier for mute/unmute of findings based on the filter.
mute_state: Option<String>Optional. All findings matching the given filter will have their mute state set to this value. The default value is MUTED. Setting this to UNDEFINED will clear the mute state on all matching findings.