pub struct GoogleCloudSecuritycenterV1CustomOutputSpec {
pub properties: Option<Vec<GoogleCloudSecuritycenterV1Property>>,
}Expand description
A set of optional name-value pairs that define custom source properties to return with each finding that is generated by the custom module. The custom source properties that are defined here are included in the finding JSON under sourceProperties.
This type is not used in any activity, and only used as part of another schema.
Fields
properties: Option<Vec<GoogleCloudSecuritycenterV1Property>>A list of custom output properties to add to the finding.