pub struct OrganizationSettings {
pub asset_discovery_config: Option<AssetDiscoveryConfig>,
pub enable_asset_discovery: Option<bool>,
pub name: Option<String>,
}Expand description
User specified settings that are attached to the Security Command Center organization.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get organization settings organizations (response)
- update organization settings organizations (request|response)
Fields
asset_discovery_config: Option<AssetDiscoveryConfig>The configuration used for Asset Discovery runs.
enable_asset_discovery: Option<bool>A flag that indicates if Asset Discovery should be enabled. If the flag is set to true, then discovery of assets will occur. If it is set to false, all historical assets will remain, but discovery of future assets will not occur.
name: Option<String>The relative resource name of the settings. See: https://cloud.google.com/apis/design/resource_names#relative_resource_name Example: “organizations/{organization_id}/organizationSettings”.